==> distfun-0.3-1-src.zip: distfun/sci_gateway/cgrand/sci_distfun_grandnf.c <==

/*
* Copyright (C)  2012 - Michael Baudin
* Copyright (C)  2001 - Bruno Pincon
* Copyright (C) ENPC
*
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

/*------------------------------------------------------------------------
*    Interface for grand
*    jpc@cermics.enpc.fr
*    stuff to deal with several generators added
*         by Bruno Pincon (12/11/2001)
*
--------------------------------------------------------------------------*/
#include <string.h>
#include <math.h>

// From Distfun:
#include "gwsupport.h"
#include "genrand.h"
#include "gw_distfungrand.h"
#include "gw_distfungrand_support.h" 

// From Scilab:
#include "api_scilab.h"
#include "stack-c.h"

/**************************************************
Y=distfun_grandnf(m,n,Dfn,Dfd,Xnon) 

generates random variates from the noncentral F (variance ratio) 
distribution with Dfn (real >= 1) degrees of freedom in the 
numerator, and Dfd (real > 0) degrees of freedom in the denominator, 
and noncentrality parameter Xnonc (real >= 0). 

Related function(s) : cdffnc.
***********************************************************************/

int sci_distfun_grandnf(char *fname,unsigned long fname_len)
{
	int rRows,rCols;
	int ma, na;
	int mb, nb;
	int mc, nc;
	int readFlag;
	double * pa = NULL;
	double * pb = NULL;
	double * pc = NULL;

	CheckRhs(5,5);
	CheckLhs(1,1);

	// Get Arg #1 = M, Arg #2 = N
	readFlag = distfun_GetMN ( fname , &rRows , &rCols );
	if ( readFlag == 0)
	{ 
		return 0;
	}
    // Arg #3 : a
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 3, &pa, &ma, &na);
	if ( readFlag == 0)
	{ 
		return 0;
	}
	// Check that a >= 1.
	readFlag = gwsupport_CheckDoubleMatrixGreaterOrEqual (fname, 3, pa, ma, na, 1.0);
	if ( readFlag == 0)
	{ 
		return 0;
	}
    // Arg #4 : b
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 4, &pb, &mb, &nb);
	if ( readFlag == 0)
	{ 
		return 0;
	}
	// Check that b > 0
	readFlag = gwsupport_CheckDoubleMatrixGreaterThan (fname, 4, pb, mb, nb, 0.0);
	if ( readFlag == 0)
	{ 
		return 0;
	}
    // Arg #5 : c
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 5, &pc, &mc, &nc);
	if ( readFlag == 0)
	{ 
		return 0;
	}
	// Check that c >= 0.
	readFlag = gwsupport_CheckDoubleMatrixGreaterOrEqual (fname, 5, pc, mc, nc, 0.0);
	if ( readFlag == 0)
	{ 
		return 0;
	}
    // Compute the result (if necessary, expand the arguments a and b and C)
	readFlag = distfun_computeRandgenABC (fname, ma, na, pa, mb, nb, pb, mc, nc, pc, rRows, rCols, C2F(gennf) );
	if ( readFlag == 0)
	{ 
		return 0;
	}
	LhsVar(1) = Rhs+1;

	return 0;
}

==> distfun-0.5-1-src.zip: distfun/sci_gateway/cgrand/sci_distfun_grandnf.c <==

/*
* Copyright (C)  2012 - Michael Baudin
* Copyright (C)  2001 - Bruno Pincon
* Copyright (C) ENPC
*
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

/*------------------------------------------------------------------------
*    Interface for grand
*    jpc@cermics.enpc.fr
*    stuff to deal with several generators added
*         by Bruno Pincon (12/11/2001)
*
--------------------------------------------------------------------------*/
#include <string.h>
#include <math.h>

// From Distfun:
#include "gwsupport.h"
#include "genrand.h"
#include "gw_distfungrand.h"
#include "gw_distfungrand_support.h" 

// From Scilab:
#include "api_scilab.h"
#include "stack-c.h"

/**************************************************
Y=distfun_grandnf(m,n,Dfn,Dfd,Xnon) 

generates random variates from the noncentral F (variance ratio) 
distribution with Dfn (real >= 1) degrees of freedom in the 
numerator, and Dfd (real > 0) degrees of freedom in the denominator, 
and noncentrality parameter Xnonc (real >= 0). 

Related function(s) : cdffnc.
***********************************************************************/

int sci_distfun_grandnf(char *fname,unsigned long fname_len)
{
	int rRows,rCols;
	int ma, na;
	int mb, nb;
	int mc, nc;
	int readFlag;
	double * pa = NULL;
	double * pb = NULL;
	double * pc = NULL;

	CheckInputArgument(pvApiCtx,5,5);
	CheckOutputArgument(pvApiCtx,1,1);

	// Get Arg #1 = M, Arg #2 = N
	readFlag = distfun_GetMN ( fname , &rRows , &rCols );
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
    // Arg #3 : a
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 3, &pa, &ma, &na);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
	// Check that a >= 1.
	readFlag = gwsupport_CheckDoubleMatrixGreaterOrEqual (fname, 3, pa, ma, na, 1.0);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
    // Arg #4 : b
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 4, &pb, &mb, &nb);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
	// Check that b > 0
	readFlag = gwsupport_CheckDoubleMatrixGreaterThan (fname, 4, pb, mb, nb, 0.0);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
    // Arg #5 : c
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 5, &pc, &mc, &nc);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
	// Check that c >= 0.
	readFlag = gwsupport_CheckDoubleMatrixGreaterOrEqual (fname, 5, pc, mc, nc, 0.0);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
    // Compute the result (if necessary, expand the arguments a and b and C)
	readFlag = distfun_computeRandgenABC (fname, ma, na, pa, mb, nb, pb, mc, nc, pc, rRows, rCols, genrand_gennf );
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
	LhsVar(1) = Rhs+1;

	return 0;
}
